@@ -7,8 +7,8 @@ from holmes.core.investigation_structured_output import process_response_into_se
 from holmes.core.issue import Issue
 from holmes.core.models import InvestigateRequest, InvestigationResult
 from holmes.core.supabase_dal import SupabaseDal
+from holmes.core.tracing import DummySpan, SpanType
 from holmes.utils.global_instructions import add_global_instructions_to_user_prompt
-from holmes.utils.robusta import load_robusta_api_key
 
 from holmes.core.investigation_structured_output import (
     DEFAULT_SECTIONS,
@@ -24,8 +24,8 @@ def investigate_issues(
     dal: SupabaseDal,
     config: Config,
     model: Optional[str] = None,
+    trace_span=DummySpan(),
 ) -> InvestigationResult:
-    load_robusta_api_key(dal=dal, config=config)
     context = dal.get_issue_data(investigate_request.context.get("robusta_issue_id"))
 
     resource_instructions = dal.get_resource_instructions(
@@ -37,7 +37,12 @@ def investigate_issues(
     if context:
         raw_data["extra_context"] = context
 
+    # If config is not preinitilized
+    create_issue_investigator_span = trace_span.start_span(
+        "create_issue_investigator", SpanType.FUNCTION.value
+    )
     ai = config.create_issue_investigator(dal=dal, model=model)
+    create_issue_investigator_span.end()
 
     issue = Issue(
         id=context["id"] if context else "",
@@ -54,6 +59,7 @@ def investigate_issues(
         instructions=resource_instructions,
         global_instructions=global_instructions,
         sections=investigate_request.sections,
+        trace_span=trace_span,
     )
 
     (text_response, sections) = process_response_into_sections(investigation.result)
@@ -64,6 +70,7 @@ def investigate_issues(
         sections=sections,
         tool_calls=investigation.tool_calls or [],
         instructions=investigation.instructions,
+        metadata=investigation.metadata,
     )
 
 
@@ -73,7 +80,6 @@ def get_investigation_context(
     config: Config,
     request_structured_output_from_llm: Optional[bool] = None,
 ):
-    load_robusta_api_key(dal=dal, config=config)
     ai = config.create_issue_investigator(dal=dal, model=investigate_request.model)
 
     raw_data = investigate_request.model_dump()
