@@ -1,7 +1,7 @@
 from holmes.core.investigation_structured_output import InputSectionsDataType
 from holmes.core.tool_calling_llm import ToolCallResult
 from typing import Optional, List, Dict, Any, Union
-from pydantic import BaseModel, model_validator
+from pydantic import BaseModel, model_validator, Field
 from enum import Enum
 
 
@@ -10,6 +10,7 @@ class InvestigationResult(BaseModel):
     sections: Optional[Dict[str, Union[str, None]]] = None
     tool_calls: List[ToolCallResult] = []
     instructions: List[str] = []
+    metadata: Optional[Dict[Any, Any]] = None
 
 
 class InvestigateRequest(BaseModel):
@@ -89,6 +90,7 @@ class ConversationRequest(BaseModel):
 class ChatRequestBaseModel(BaseModel):
     conversation_history: Optional[list[dict]] = None
     model: Optional[str] = None
+    stream: bool = Field(default=False)
 
     # In our setup with litellm, the first message in conversation_history
     # should follow the structure [{"role": "system", "content": ...}],
@@ -144,12 +146,20 @@ class ChatResponse(BaseModel):
     conversation_history: list[dict]
     tool_calls: Optional[List[ToolCallResult]] = []
     follow_up_actions: Optional[List[FollowUpAction]] = []
+    metadata: Optional[Dict[Any, Any]] = None
 
 
 class WorkloadHealthInvestigationResult(BaseModel):
     analysis: Optional[str] = None
     tools: Optional[List[ToolCallConversationResult]] = []
 
+    @model_validator(mode="before")
+    def check_analysis_and_result(cls, values):
+        if "result" in values and "analysis" not in values:
+            values["analysis"] = values["result"]
+            del values["result"]
+        return values
+
 
 class WorkloadHealthChatRequest(ChatRequestBaseModel):
     ask: str
