@@ -37,6 +37,7 @@ from holmes.utils.global_instructions import Instructions
 SUPABASE_TIMEOUT_SECONDS = int(os.getenv("SUPABASE_TIMEOUT_SECONDS", 3600))
 
 ISSUES_TABLE = "Issues"
+GROUPED_ISSUES_TABLE = "GroupedIssues"
 EVIDENCE_TABLE = "Evidence"
 RUNBOOKS_TABLE = "HolmesRunbooks"
 SESSION_TOKENS_TABLE = "AuthTokens"
@@ -131,7 +132,7 @@ class SupabaseDal:
                         raise Exception(
                             "No robusta token provided to Holmes.\n"
                             "Please set a valid Robusta UI token.\n "
-                            "See https://docs.robusta.dev/master/configuration/ai-analysis.html#choosing-and-configuring-an-ai-provider for instructions."
+                            "See https://holmesgpt.dev/ai-providers/ for instructions."
                         )
                     env_replacement_token = get_env_replacement(token)
                     if env_replacement_token:
@@ -143,7 +144,7 @@ class SupabaseDal:
                             "Ensure your Helm chart or environment variables are set correctly.\n "
                             "If you store the token in a secret, you must also pass "
                             "the environment variable ROBUSTA_UI_TOKEN to Holmes.\n "
-                            "See https://docs.robusta.dev/master/configuration/ai-analysis.html#configuring-holmesgpt-access-to-saas-data for instructions."
+                            "See https://holmesgpt.dev/data-sources/builtin-toolsets/robusta/ for instructions."
                         )
                     try:
                         decoded = base64.b64decode(token)
@@ -338,6 +339,14 @@ class SupabaseDal:
         data.extend(unzipped_files)
         return data
 
+    def get_issue_from_db(self, issue_id: str, table: str) -> Optional[Dict]:
+        issue_response = (
+            self.client.table(table).select("*").filter("id", "eq", issue_id).execute()
+        )
+        if len(issue_response.data):
+            return issue_response.data[0]
+        return None
+
     def get_issue_data(self, issue_id: Optional[str]) -> Optional[Dict]:
         # TODO this could be done in a single atomic SELECT, but there is no
         # foreign key relation between Issues and Evidence.
@@ -347,14 +356,11 @@ class SupabaseDal:
             return None
         issue_data = None
         try:
-            issue_response = (
-                self.client.table(ISSUES_TABLE)
-                .select("*")
-                .filter("id", "eq", issue_id)
-                .execute()
-            )
-            if len(issue_response.data):
-                issue_data = issue_response.data[0]
+            issue_data = self.get_issue_from_db(issue_id, ISSUES_TABLE)
+            if issue_data and issue_data["source"] == "prometheus":
+                logging.debug("Getting alert %s from GroupedIssuesTable", issue_id)
+                # This issue will have the complete alert duration information
+                issue_data = self.get_issue_from_db(issue_id, GROUPED_ISSUES_TABLE)
 
         except Exception:  # e.g. invalid id format
             logging.exception("Supabase error while retrieving issue data")
@@ -427,6 +433,9 @@ class SupabaseDal:
         return None
 
     def get_global_instructions_for_account(self) -> Optional[Instructions]:
+        if not self.enabled:
+            return None
+
         try:
             res = (
                 self.client.table(RUNBOOKS_TABLE)
