@@ -6,7 +6,7 @@ import sentry_sdk
 from holmes.core.tools import (
     StructuredToolResult,
     Tool,
-    ToolResultStatus,
+    StructuredToolResultStatus,
     Toolset,
     ToolsetStatusEnum,
 )
@@ -38,6 +38,8 @@ class ToolExecutor:
         self.tools_by_name: dict[str, Tool] = {}
         for ts in toolsets_by_name.values():
             for tool in ts.tools:
+                if tool.icon_url is None and ts.icon_url is not None:
+                    tool.icon_url = ts.icon_url
                 if tool.name in self.tools_by_name:
                     logging.warning(
                         f"Overriding existing tool '{tool.name} with new tool from {ts.name} at {ts.path}'!"
@@ -50,7 +52,7 @@ class ToolExecutor:
             tool.invoke(params)
             if tool
             else StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=f"Could not find tool named {tool_name}",
             )
         )
@@ -62,5 +64,8 @@ class ToolExecutor:
         return None
 
     @sentry_sdk.trace
-    def get_all_tools_openai_format(self):
-        return [tool.get_openai_format() for tool in self.tools_by_name.values()]
+    def get_all_tools_openai_format(self, target_model: str):
+        return [
+            tool.get_openai_format(target_model=target_model)
+            for tool in self.tools_by_name.values()
+        ]
