@@ -27,10 +27,11 @@ from pygments.lexers import guess_lexer
 from rich.console import Console
 from rich.markdown import Markdown, Panel
 
+from holmes.common.env_vars import ENABLE_CLI_TOOL_APPROVAL
 from holmes.core.config import config_path_dir
 from holmes.core.prompt import build_initial_ask_messages
 from holmes.core.tool_calling_llm import ToolCallingLLM, ToolCallResult
-from holmes.core.tools import pretty_print_toolset_status
+from holmes.core.tools import StructuredToolResult, pretty_print_toolset_status
 from holmes.core.tracing import DummyTracer
 from holmes.utils.colors import (
     AI_COLOR,
@@ -584,6 +585,53 @@ def prompt_for_llm_sharing(
     return None
 
 
+def handle_tool_approval(
+    command: Optional[str],
+    error_message: Optional[str],
+    style: Style,
+    console: Console,
+) -> tuple[bool, Optional[str]]:
+    """
+    Handle user approval for potentially sensitive commands.
+
+    Args:
+        command: The command that needs approval
+        error_message: The error message explaining why approval is needed
+        session: PromptSession for user input
+        style: Style for prompts
+        console: Rich console for output
+
+    Returns:
+        Tuple of (approved: bool, feedback: Optional[str])
+        - approved: True if user approves, False if denied
+        - feedback: User's optional feedback message when denying
+    """
+    console.print("\n[bold yellow]⚠️  Command Approval Required[/bold yellow]")
+    console.print(f"[yellow]Command:[/yellow] {command or 'unknown'}")
+    console.print(f"[yellow]Reason:[/yellow] {error_message or 'unknown'}")
+    console.print()
+
+    # Create a temporary session without history for approval prompts
+    temp_session = PromptSession(history=InMemoryHistory())  # type: ignore
+
+    approval_prompt = temp_session.prompt(
+        [("class:prompt", "Do you want to approve and execute this command? (y/N): ")],
+        style=style,
+    )
+
+    if approval_prompt.lower().startswith("y"):
+        return True, None
+    else:
+        # Ask for optional feedback when denying
+        feedback_prompt = temp_session.prompt(
+            [("class:prompt", "Optional feedback for the AI (press Enter to skip): ")],
+            style=style,
+        )
+
+        feedback = feedback_prompt.strip() if feedback_prompt.strip() else None
+        return False, feedback
+
+
 def handle_run_command(
     bash_command: str, session: PromptSession, style: Style, console: Console
 ) -> Optional[str]:
@@ -811,6 +859,20 @@ def run_interactive_loop(
         }
     )
 
+    # Set up approval callback for potentially sensitive commands
+    def approval_handler(
+        tool_call_result: StructuredToolResult,
+    ) -> tuple[bool, Optional[str]]:
+        return handle_tool_approval(
+            command=tool_call_result.invocation,
+            error_message=tool_call_result.error,
+            style=style,
+            console=console,
+        )
+
+    if ENABLE_CLI_TOOL_APPROVAL:
+        ai.approval_callback = approval_handler
+
     # Create merged completer with slash commands, conditional executables, show command, and smart paths
     slash_completer = SlashCommandCompleter()
     executable_completer = ConditionalExecutableCompleter()
