@@ -2,7 +2,7 @@ import logging
 from typing import Dict
 from datetime import datetime, timezone
 
-from holmes.core.tools import StructuredToolResult, ToolResultStatus
+from holmes.core.tools import StructuredToolResult, StructuredToolResultStatus
 from holmes.plugins.toolsets.azure_sql.azure_base_toolset import (
     BaseAzureSQLTool,
     BaseAzureSQLToolset,
@@ -11,6 +11,8 @@ from holmes.plugins.toolsets.azure_sql.azure_base_toolset import (
 from holmes.plugins.toolsets.azure_sql.apis.azure_sql_api import AzureSQLAPIClient
 from typing import Tuple
 
+from holmes.plugins.toolsets.utils import toolset_name_for_one_liner
+
 
 class AnalyzeDatabaseHealthStatus(BaseAzureSQLTool):
     def __init__(self, toolset: "BaseAzureSQLToolset"):
@@ -129,7 +131,9 @@ class AnalyzeDatabaseHealthStatus(BaseAzureSQLTool):
 
         return "\n".join(report_sections)
 
-    def _invoke(self, params: Dict) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         try:
             db_config = self.toolset.database_config()
             client = self.toolset.api_client()
@@ -141,7 +145,7 @@ class AnalyzeDatabaseHealthStatus(BaseAzureSQLTool):
             report_text = self._build_health_report(health_data, db_config)
 
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=report_text,
                 params=params,
             )
@@ -149,14 +153,14 @@ class AnalyzeDatabaseHealthStatus(BaseAzureSQLTool):
             error_msg = f"Failed to generate health report: {str(e)}"
             logging.error(error_msg)
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=error_msg,
                 params=params,
             )
 
     def get_parameterized_one_liner(self, params: Dict) -> str:
         db_config = self.toolset.database_config()
-        return f"Analyze health status for database {db_config.server_name}/{db_config.database_name}"
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Analyze Health Status ({db_config.server_name}/{db_config.database_name})"
 
     @staticmethod
     def validate_config(
