@@ -2,13 +2,14 @@ import logging
 from typing import Any, Dict, List, Tuple, cast
 from datetime import datetime, timezone
 
-from holmes.core.tools import StructuredToolResult, ToolResultStatus
+from holmes.core.tools import StructuredToolResult, StructuredToolResultStatus
 from holmes.plugins.toolsets.azure_sql.azure_base_toolset import (
     BaseAzureSQLTool,
     BaseAzureSQLToolset,
     AzureSQLDatabaseConfig,
 )
 from holmes.plugins.toolsets.azure_sql.apis.azure_sql_api import AzureSQLAPIClient
+from holmes.plugins.toolsets.utils import toolset_name_for_one_liner
 
 
 class AnalyzeDatabasePerformance(BaseAzureSQLTool):
@@ -191,7 +192,9 @@ class AnalyzeDatabasePerformance(BaseAzureSQLTool):
 
         return "\n".join(report_sections)
 
-    def _invoke(self, params: Dict) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         try:
             db_config = self.toolset.database_config()
             client = self.toolset.api_client()
@@ -203,7 +206,7 @@ class AnalyzeDatabasePerformance(BaseAzureSQLTool):
             report_text = self._build_performance_report(performance_data, db_config)
 
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=report_text,
                 params=params,
             )
@@ -211,14 +214,14 @@ class AnalyzeDatabasePerformance(BaseAzureSQLTool):
             error_msg = f"Failed to generate performance report: {str(e)}"
             logging.error(error_msg)
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=error_msg,
                 params=params,
             )
 
     def get_parameterized_one_liner(self, params: Dict) -> str:
         db_config = self.toolset.database_config()
-        return f"Analyze performance for database {db_config.server_name}/{db_config.database_name}"
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Analyze Database Performance ({db_config.server_name}/{db_config.database_name})"
 
     @staticmethod
     def validate_config(
