@@ -2,7 +2,11 @@ import logging
 from typing import Any, Dict, Tuple
 from datetime import datetime, timezone
 
-from holmes.core.tools import StructuredToolResult, ToolParameter, ToolResultStatus
+from holmes.core.tools import (
+    StructuredToolResult,
+    ToolParameter,
+    StructuredToolResultStatus,
+)
 from holmes.plugins.toolsets.azure_sql.azure_base_toolset import (
     BaseAzureSQLTool,
     BaseAzureSQLToolset,
@@ -12,6 +16,7 @@ from holmes.plugins.toolsets.azure_sql.apis.storage_analysis_api import (
     StorageAnalysisAPI,
 )
 from holmes.plugins.toolsets.azure_sql.apis.azure_sql_api import AzureSQLAPIClient
+from holmes.plugins.toolsets.utils import toolset_name_for_one_liner
 
 
 class AnalyzeDatabaseStorage(BaseAzureSQLTool):
@@ -248,7 +253,9 @@ class AnalyzeDatabaseStorage(BaseAzureSQLTool):
 
         return "\n".join(report_sections)
 
-    def _invoke(self, params: Dict) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         try:
             hours_back = params.get("hours_back", 24)
             top_tables = params.get("top_tables", 20)
@@ -304,7 +311,7 @@ class AnalyzeDatabaseStorage(BaseAzureSQLTool):
             )
 
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=report_text,
                 params=params,
             )
@@ -312,14 +319,14 @@ class AnalyzeDatabaseStorage(BaseAzureSQLTool):
             error_msg = f"Failed to generate storage report: {str(e)}"
             logging.error(error_msg)
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=error_msg,
                 params=params,
             )
 
     def get_parameterized_one_liner(self, params: Dict) -> str:
         db_config = self.toolset.database_config()
-        return f"Analyzed database storage for database {db_config.server_name}/{db_config.database_name}"
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Analyze Database Storage ({db_config.server_name}/{db_config.database_name})"
 
     @staticmethod
     def validate_config(
