@@ -1,9 +1,9 @@
-from typing import Any, Optional, Tuple
+from typing import Any, Optional, Tuple, Set
 
 from holmes.core.tools import (
     CallablePrerequisite,
     StructuredToolResult,
-    ToolResultStatus,
+    StructuredToolResultStatus,
     ToolsetTag,
 )
 from holmes.plugins.toolsets.consts import (
@@ -23,23 +23,29 @@ from holmes.plugins.toolsets.coralogix.utils import (
 from holmes.plugins.toolsets.logging_utils.logging_api import (
     BasePodLoggingToolset,
     FetchPodLogsParams,
+    LoggingCapability,
     PodLoggingTool,
 )
 
 
 class CoralogixLogsToolset(BasePodLoggingToolset):
+    @property
+    def supported_capabilities(self) -> Set[LoggingCapability]:
+        """Coralogix only supports substring matching, not regex or exclude filters"""
+        return set()  # No regex support, no exclude filter
+
     def __init__(self):
         super().__init__(
             name="coralogix/logs",
             description="Toolset for interacting with Coralogix to fetch logs",
-            docs_url="https://docs.robusta.dev/master/configuration/holmesgpt/toolsets/coralogix_logs.html",
+            docs_url="https://holmesgpt.dev/data-sources/builtin-toolsets/coralogix-logs/",
             icon_url="https://avatars.githubusercontent.com/u/35295744?s=200&v=4",
             prerequisites=[CallablePrerequisite(callable=self.prerequisites_callable)],
-            tools=[
-                PodLoggingTool(self),
-            ],
+            tools=[],  # Initialize with empty tools first
             tags=[ToolsetTag.CORE],
         )
+        # Now that parent is initialized and self.name exists, create the tool
+        self.tools = [PodLoggingTool(self)]
 
     def get_example_config(self):
         example_config = CoralogixConfig(
@@ -68,7 +74,7 @@ class CoralogixLogsToolset(BasePodLoggingToolset):
     def fetch_pod_logs(self, params: FetchPodLogsParams) -> StructuredToolResult:
         if not self.coralogix_config:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=f"The {self.name} toolset is not configured",
                 params=params.model_dump(),
             )
@@ -96,7 +102,9 @@ class CoralogixLogsToolset(BasePodLoggingToolset):
 
         return StructuredToolResult(
             status=(
-                ToolResultStatus.ERROR if logs_data.error else ToolResultStatus.SUCCESS
+                StructuredToolResultStatus.ERROR
+                if logs_data.error
+                else StructuredToolResultStatus.SUCCESS
             ),
             error=logs_data.error,
             data=data,
