@@ -1,3 +1,5 @@
+"""Datadog Traces toolset for HolmesGPT."""
+
 import json
 import logging
 import os
@@ -10,7 +12,7 @@ from holmes.core.tools import (
     ToolParameter,
     Toolset,
     StructuredToolResult,
-    ToolResultStatus,
+    StructuredToolResultStatus,
     ToolsetTag,
 )
 from holmes.plugins.toolsets.datadog.datadog_api import (
@@ -20,12 +22,18 @@ from holmes.plugins.toolsets.datadog.datadog_api import (
     get_headers,
     MAX_RETRY_COUNT_ON_RATE_LIMIT,
 )
-from holmes.plugins.toolsets.utils import process_timestamps_to_int
+from holmes.plugins.toolsets.utils import (
+    process_timestamps_to_int,
+    toolset_name_for_one_liner,
+)
 from holmes.plugins.toolsets.datadog.datadog_traces_formatter import (
     format_traces_list,
     format_trace_hierarchy,
     format_spans_search,
 )
+from holmes.plugins.toolsets.logging_utils.logging_api import (
+    DEFAULT_TIME_SPAN_SECONDS,
+)
 
 
 class DatadogTracesConfig(DatadogBaseConfig):
@@ -41,7 +49,7 @@ class DatadogTracesToolset(Toolset):
         super().__init__(
             name="datadog/traces",
             description="Toolset for interacting with Datadog APM to fetch and analyze traces",
-            docs_url="https://docs.datadoghq.com/api/latest/spans/",
+            docs_url="https://holmesgpt.dev/data-sources/builtin-toolsets/datadog/",
             icon_url="https://imgix.datadoghq.com//img/about/presskit/DDlogo.jpg",
             prerequisites=[CallablePrerequisite(callable=self.prerequisites_callable)],
             tools=[
@@ -49,7 +57,6 @@ class DatadogTracesToolset(Toolset):
                 FetchDatadogTraceById(toolset=self),
                 FetchDatadogSpansByFilter(toolset=self),
             ],
-            experimental=True,
             tags=[ToolsetTag.CORE],
         )
         self._reload_instructions()
@@ -149,7 +156,7 @@ class FetchDatadogTracesList(BaseDatadogTracesTool):
     def __init__(self, toolset: "DatadogTracesToolset"):
         super().__init__(
             name="fetch_datadog_traces",
-            description="Fetch a list of traces from Datadog with optional filters",
+            description="[datadog/traces toolset] Fetch a list of traces from Datadog with optional filters",
             parameters={
                 "service": ToolParameter(
                     description="Filter by service name",
@@ -200,14 +207,16 @@ class FetchDatadogTracesList(BaseDatadogTracesTool):
         if "min_duration" in params:
             filters.append(f"duration>{params['min_duration']}")
 
-        filter_str = " AND ".join(filters) if filters else "all traces"
-        return f"DataDog: fetch traces matching {filter_str}"
+        filter_str = ", ".join(filters) if filters else "all"
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Fetch Traces ({filter_str})"
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         """Execute the tool to fetch traces."""
         if not self.toolset.dd_config:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error="Datadog configuration not initialized",
                 params=params,
             )
@@ -220,7 +229,7 @@ class FetchDatadogTracesList(BaseDatadogTracesTool):
             from_time_int, to_time_int = process_timestamps_to_int(
                 start=params.get("start_datetime"),
                 end=params.get("end_datetime"),
-                default_time_span_seconds=3600,  # Default to 1 hour
+                default_time_span_seconds=DEFAULT_TIME_SPAN_SECONDS,
             )
 
             # Convert to milliseconds for Datadog API
@@ -296,13 +305,13 @@ class FetchDatadogTracesList(BaseDatadogTracesTool):
             formatted_output = format_traces_list(spans, limit=params.get("limit", 50))
             if not formatted_output:
                 return StructuredToolResult(
-                    status=ToolResultStatus.NO_DATA,
+                    status=StructuredToolResultStatus.NO_DATA,
                     params=params,
                     data="No matching traces found.",
                 )
 
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=formatted_output,
                 params=params,
             )
@@ -321,7 +330,7 @@ class FetchDatadogTracesList(BaseDatadogTracesTool):
                 error_msg = f"Exception while querying Datadog: {str(e)}"
 
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=error_msg,
                 params=params,
                 invocation=(
@@ -334,7 +343,7 @@ class FetchDatadogTracesList(BaseDatadogTracesTool):
         except Exception as e:
             logging.exception(e, exc_info=True)
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=f"Unexpected error: {str(e)}",
                 params=params,
                 invocation=(
@@ -351,7 +360,7 @@ class FetchDatadogTraceById(BaseDatadogTracesTool):
     def __init__(self, toolset: "DatadogTracesToolset"):
         super().__init__(
             name="fetch_datadog_trace_by_id",
-            description="Fetch detailed information about a specific trace by its ID",
+            description="[datadog/traces toolset] Fetch detailed information about a specific trace by its ID",
             parameters={
                 "trace_id": ToolParameter(
                     description="The trace ID to fetch details for",
@@ -364,15 +373,16 @@ class FetchDatadogTraceById(BaseDatadogTracesTool):
 
     def get_parameterized_one_liner(self, params: dict) -> str:
         """Get a one-liner description of the tool invocation."""
-        return (
-            f"DataDog: fetch trace details for ID {params.get('trace_id', 'unknown')}"
-        )
+        trace_id = params.get("trace_id", "unknown")
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Fetch Trace Details ({trace_id})"
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         """Execute the tool to fetch trace details."""
         if not self.toolset.dd_config:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error="Datadog configuration not initialized",
                 params=params,
             )
@@ -380,7 +390,7 @@ class FetchDatadogTraceById(BaseDatadogTracesTool):
         trace_id = params.get("trace_id")
         if not trace_id:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error="trace_id parameter is required",
                 params=params,
             )
@@ -434,13 +444,13 @@ class FetchDatadogTraceById(BaseDatadogTracesTool):
             formatted_output = format_trace_hierarchy(trace_id, spans)
             if not formatted_output:
                 return StructuredToolResult(
-                    status=ToolResultStatus.NO_DATA,
+                    status=StructuredToolResultStatus.NO_DATA,
                     params=params,
                     data=f"No trace found for trace_id: {trace_id}",
                 )
 
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=formatted_output,
                 params=params,
             )
@@ -459,7 +469,7 @@ class FetchDatadogTraceById(BaseDatadogTracesTool):
                 error_msg = f"Exception while querying Datadog: {str(e)}"
 
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=error_msg,
                 params=params,
                 invocation=(
@@ -472,7 +482,7 @@ class FetchDatadogTraceById(BaseDatadogTracesTool):
         except Exception as e:
             logging.exception(e, exc_info=True)
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=f"Unexpected error: {str(e)}",
                 params=params,
                 invocation=(
@@ -489,7 +499,7 @@ class FetchDatadogSpansByFilter(BaseDatadogTracesTool):
     def __init__(self, toolset: "DatadogTracesToolset"):
         super().__init__(
             name="fetch_datadog_spans",
-            description="Search for spans in Datadog with detailed filters",
+            description="[datadog/traces toolset] Search for spans in Datadog with detailed filters",
             parameters={
                 "query": ToolParameter(
                     description="Datadog search query (e.g., 'service:web-app @http.status_code:500')",
@@ -538,7 +548,7 @@ class FetchDatadogSpansByFilter(BaseDatadogTracesTool):
     def get_parameterized_one_liner(self, params: dict) -> str:
         """Get a one-liner description of the tool invocation."""
         if "query" in params:
-            return f"DataDog: search spans with query: {params['query']}"
+            return f"{toolset_name_for_one_liner(self.toolset.name)}: Search Spans ({params['query']})"
 
         filters = []
         if "service" in params:
@@ -546,14 +556,16 @@ class FetchDatadogSpansByFilter(BaseDatadogTracesTool):
         if "operation" in params:
             filters.append(f"operation={params['operation']}")
 
-        filter_str = " AND ".join(filters) if filters else "all spans"
-        return f"DataDog: search spans matching {filter_str}"
+        filter_str = ", ".join(filters) if filters else "all"
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Search Spans ({filter_str})"
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         """Execute the tool to search spans."""
         if not self.toolset.dd_config:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error="Datadog configuration not initialized",
                 params=params,
             )
@@ -566,7 +578,7 @@ class FetchDatadogSpansByFilter(BaseDatadogTracesTool):
             from_time_int, to_time_int = process_timestamps_to_int(
                 start=params.get("start_datetime"),
                 end=params.get("end_datetime"),
-                default_time_span_seconds=3600,  # Default to 1 hour
+                default_time_span_seconds=DEFAULT_TIME_SPAN_SECONDS,
             )
 
             # Convert to milliseconds for Datadog API
@@ -641,13 +653,13 @@ class FetchDatadogSpansByFilter(BaseDatadogTracesTool):
             formatted_output = format_spans_search(spans)
             if not formatted_output:
                 return StructuredToolResult(
-                    status=ToolResultStatus.NO_DATA,
+                    status=StructuredToolResultStatus.NO_DATA,
                     params=params,
                     data="No matching spans found.",
                 )
 
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=formatted_output,
                 params=params,
             )
@@ -665,7 +677,7 @@ class FetchDatadogSpansByFilter(BaseDatadogTracesTool):
                 error_msg = f"Exception while querying Datadog: {str(e)}"
 
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=error_msg,
                 params=params,
                 invocation=(
@@ -678,7 +690,7 @@ class FetchDatadogSpansByFilter(BaseDatadogTracesTool):
         except Exception as e:
             logging.exception(e, exc_info=True)
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=f"Unexpected error: {str(e)}",
                 params=params,
                 invocation=(
