@@ -1,10 +1,17 @@
 from typing import Dict, List
 from urllib.parse import urlencode, urljoin
-from holmes.core.tools import Tool, ToolParameter
+from holmes.core.tools import (
+    StructuredToolResult,
+    Tool,
+    ToolParameter,
+    StructuredToolResultStatus,
+)
 from holmes.plugins.toolsets.grafana.base_grafana_toolset import BaseGrafanaToolset
 import requests  # type: ignore
 import logging
 
+from holmes.plugins.toolsets.utils import toolset_name_for_one_liner
+
 
 class ListAndBuildGrafanaDashboardURLs(Tool):
     def __init__(self, toolset: BaseGrafanaToolset):
@@ -36,7 +43,9 @@ class ListAndBuildGrafanaDashboardURLs(Tool):
         )
         self._toolset = toolset
 
-    def _invoke(self, params: Dict) -> str:  # type: ignore
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         url = urljoin(
             self._toolset._grafana_config.url, "/api/search?query=&type=dash-db"
         )
@@ -80,13 +89,29 @@ class ListAndBuildGrafanaDashboardURLs(Tool):
                     f"Title: {dash['title']}\nURL: {dashboard_url}\n"
                 )
 
-            return "\n".join(formatted_dashboards) or "No dashboards found."
+            return StructuredToolResult(
+                status=StructuredToolResultStatus.SUCCESS
+                if formatted_dashboards
+                else StructuredToolResultStatus.NO_DATA,
+                data="\n".join(formatted_dashboards)
+                if formatted_dashboards
+                else "No dashboards found.",
+                url=url,
+                params=params,
+            )
         except requests.RequestException as e:
             logging.error(f"Error fetching dashboards: {str(e)}")
-            return f"Error fetching dashboards: {str(e)}"
+            return StructuredToolResult(
+                status=StructuredToolResultStatus.ERROR,
+                error=f"Error fetching dashboards: {str(e)}",
+                url=url,
+                params=params,
+            )
 
     def get_parameterized_one_liner(self, params: Dict) -> str:
-        return f"Lists Grafana dashboards and builds URLs with parameters: {params}"
+        return (
+            f"{toolset_name_for_one_liner(self._toolset.name)}: List Grafana Dashboards"
+        )
 
 
 class GrafanaToolset(BaseGrafanaToolset):
