@@ -1,4 +1,4 @@
-from typing import Any, cast
+from typing import Any, cast, Set
 from pydantic import BaseModel
 
 from holmes.core.tools import CallablePrerequisite
@@ -11,7 +11,10 @@ from holmes.plugins.toolsets.grafana.grafana_api import grafana_health_check
 from holmes.plugins.toolsets.logging_utils.logging_api import (
     BasePodLoggingToolset,
     FetchPodLogsParams,
+    LoggingCapability,
     PodLoggingTool,
+    DEFAULT_TIME_SPAN_SECONDS,
+    DEFAULT_LOG_LIMIT,
 )
 from holmes.plugins.toolsets.utils import (
     process_timestamps_to_rfc3339,
@@ -20,9 +23,7 @@ from holmes.plugins.toolsets.utils import (
 from holmes.plugins.toolsets.grafana.loki_api import (
     query_loki_logs_by_label,
 )
-from holmes.core.tools import StructuredToolResult, ToolResultStatus
-
-DEFAULT_TIME_SPAN_SECONDS = 3600
+from holmes.core.tools import StructuredToolResult, StructuredToolResultStatus
 
 
 class GrafanaLokiLabelsConfig(BaseModel):
@@ -35,21 +36,26 @@ class GrafanaLokiConfig(GrafanaConfig):
 
 
 class GrafanaLokiToolset(BasePodLoggingToolset):
+    @property
+    def supported_capabilities(self) -> Set[LoggingCapability]:
+        """Loki only supports substring matching, not regex or exclude filters"""
+        return set()  # No regex support, no exclude filter
+
     def __init__(self):
         super().__init__(
             name="grafana/loki",
             description="Fetches kubernetes pods logs from Loki",
             icon_url="https://grafana.com/media/docs/loki/logo-grafana-loki.png",
-            docs_url="https://docs.robusta.dev/master/configuration/holmesgpt/toolsets/grafanaloki.html",
+            docs_url="https://holmesgpt.dev/data-sources/builtin-toolsets/grafanaloki/",
             prerequisites=[CallablePrerequisite(callable=self.prerequisites_callable)],
-            tools=[
-                PodLoggingTool(self),
-            ],
+            tools=[],  # Initialize with empty tools first
         )
+        # Now that parent is initialized and self.name exists, create the tool
+        self.tools = [PodLoggingTool(self)]
 
     def prerequisites_callable(self, config: dict[str, Any]) -> tuple[bool, str]:
         if not config:
-            return False, "Missing Grafana Loki configuration. Check your config."
+            return False, "Missing Loki configuration. Check your config."
 
         self.config = GrafanaLokiConfig(**config)
 
@@ -89,17 +95,17 @@ class GrafanaLokiToolset(BasePodLoggingToolset):
             label_value=params.pod_name,
             start=start,
             end=end,
-            limit=params.limit or 2000,
+            limit=params.limit or DEFAULT_LOG_LIMIT,
         )
         if logs:
             logs.sort(key=lambda x: x["timestamp"])
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data="\n".join([format_log(log) for log in logs]),
                 params=params.model_dump(),
             )
         else:
             return StructuredToolResult(
-                status=ToolResultStatus.NO_DATA,
+                status=StructuredToolResultStatus.NO_DATA,
                 params=params.model_dump(),
             )
