@@ -15,7 +15,8 @@ from markdownify import markdownify
 from bs4 import BeautifulSoup
 
 import requests  # type: ignore
-from holmes.core.tools import StructuredToolResult, ToolResultStatus
+from holmes.core.tools import StructuredToolResult, StructuredToolResultStatus
+from holmes.plugins.toolsets.utils import toolset_name_for_one_liner
 
 
 # TODO: change and make it holmes
@@ -185,7 +186,9 @@ class FetchWebpage(Tool):
             toolset=toolset,  # type: ignore
         )
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         url: str = params["url"]
 
         additional_headers = (
@@ -196,7 +199,7 @@ class FetchWebpage(Tool):
         if not content:
             logging.error(f"Failed to retrieve content from {url}")
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=f"Failed to retrieve content from {url}",
                 params=params,
             )
@@ -208,14 +211,14 @@ class FetchWebpage(Tool):
             content = html_to_markdown(content)
 
         return StructuredToolResult(
-            status=ToolResultStatus.SUCCESS,
+            status=StructuredToolResultStatus.SUCCESS,
             data=content,
             params=params,
         )
 
     def get_parameterized_one_liner(self, params) -> str:
         url: str = params.get("url", "<missing url>")
-        return f"fetched webpage {url}"
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Fetch Webpage {url}"
 
 
 class InternetBaseToolset(Toolset):
@@ -267,7 +270,7 @@ class InternetToolset(InternetBaseToolset):
             tools=[
                 FetchWebpage(self),
             ],
-            docs_url="https://docs.robusta.dev/master/configuration/holmesgpt/toolsets/internet.html",
+            docs_url="https://holmesgpt.dev/data-sources/builtin-toolsets/internet/",
             tags=[
                 ToolsetTag.CORE,
             ],
