@@ -3,7 +3,7 @@ from holmes.core.tools import (
     Tool,
     ToolParameter,
     StructuredToolResult,
-    ToolResultStatus,
+    StructuredToolResultStatus,
     CallablePrerequisite,
 )
 
@@ -24,12 +24,14 @@ class RemoteMCPTool(Tool):
     url: str
     headers: Optional[Dict[str, str]] = None
 
-    def _invoke(self, params: Dict) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         try:
             return asyncio.run(self._invoke_async(params))
         except Exception as e:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 error=str(e.args),
                 params=params,
                 invocation=f"MCPtool {self.name} with params {params}",
@@ -46,9 +48,9 @@ class RemoteMCPTool(Tool):
                 )
                 return StructuredToolResult(
                     status=(
-                        ToolResultStatus.ERROR
+                        StructuredToolResultStatus.ERROR
                         if tool_result.isError
-                        else ToolResultStatus.SUCCESS
+                        else StructuredToolResultStatus.SUCCESS
                     ),
                     data=merged_text,
                     params=params,
@@ -83,7 +85,7 @@ class RemoteMCPTool(Tool):
         return parameters
 
     def get_parameterized_one_liner(self, params: Dict) -> str:
-        return f"Call mcp server {self.url} tool {self.name} with params {str(params)}"
+        return f"Call MCP Server ({self.url} - {self.name})"
 
 
 class RemoteMCPToolset(Toolset):
