@@ -9,7 +9,8 @@ from holmes.core.tools import (
     ToolsetTag,
 )
 from pydantic import BaseModel
-from holmes.core.tools import StructuredToolResult, ToolResultStatus
+from holmes.core.tools import StructuredToolResult, StructuredToolResultStatus
+from holmes.plugins.toolsets.utils import get_param_or_raise, toolset_name_for_one_liner
 
 
 class BaseNewRelicTool(Tool):
@@ -36,17 +37,19 @@ class GetLogs(BaseNewRelicTool):
             toolset=toolset,
         )
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         def success(msg: Any) -> StructuredToolResult:
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=msg,
                 params=params,
             )
 
         def error(msg: str) -> StructuredToolResult:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 data=msg,
                 params=params,
             )
@@ -76,7 +79,7 @@ class GetLogs(BaseNewRelicTool):
 
         try:
             logging.info(f"Getting New Relic logs for app {app} since {since}")
-            response = requests.post(url, headers=headers, json=query)
+            response = requests.post(url, headers=headers, json=query)  # type: ignore[arg-type]
 
             if response.status_code == 200:
                 return success(response.json())
@@ -89,7 +92,9 @@ class GetLogs(BaseNewRelicTool):
             return error(f"Error while fetching logs: {str(e)}")
 
     def get_parameterized_one_liner(self, params) -> str:
-        return f"newrelic GetLogs(app='{params.get('app')}', since='{params.get('since')}')"
+        app = params.get("app", "")
+        since = params.get("since", "")
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Get Logs ({app} - {since})"
 
 
 class GetTraces(BaseNewRelicTool):
@@ -112,22 +117,24 @@ class GetTraces(BaseNewRelicTool):
             toolset=toolset,
         )
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         def success(msg: Any) -> StructuredToolResult:
             return StructuredToolResult(
-                status=ToolResultStatus.SUCCESS,
+                status=StructuredToolResultStatus.SUCCESS,
                 data=msg,
                 params=params,
             )
 
         def error(msg: str) -> StructuredToolResult:
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 data=msg,
                 params=params,
             )
 
-        duration = params.get("duration")
+        duration = get_param_or_raise(params, "duration")
         trace_id = params.get("trace_id")
 
         if trace_id:
@@ -157,7 +164,7 @@ class GetTraces(BaseNewRelicTool):
 
         try:
             logging.info(f"Getting New Relic traces with duration > {duration}s")
-            response = requests.post(url, headers=headers, json=query)
+            response = requests.post(url, headers=headers, json=query)  # type: ignore[arg-type]
 
             if response.status_code == 200:
                 return success(response.json())
@@ -171,8 +178,10 @@ class GetTraces(BaseNewRelicTool):
 
     def get_parameterized_one_liner(self, params) -> str:
         if "trace_id" in params and params["trace_id"]:
-            return f"newrelic GetTraces(trace_id='{params.get('trace_id')}')"
-        return f"newrelic GetTraces(duration={params.get('duration')})"
+            trace_id = params.get("trace_id", "")
+            return f"{toolset_name_for_one_liner(self.toolset.name)}: Get Trace Details ({trace_id})"
+        duration = params.get("duration", "")
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Get Traces (>{duration}s)"
 
 
 class NewrelicConfig(BaseModel):
@@ -188,7 +197,7 @@ class NewRelicToolset(Toolset):
         super().__init__(
             name="newrelic",
             description="Toolset for interacting with New Relic to fetch logs and traces",
-            docs_url="https://docs.newrelic.com/docs/apis/nerdgraph-api/",
+            docs_url="https://holmesgpt.dev/data-sources/builtin-toolsets/newrelic/",
             icon_url="https://companieslogo.com/img/orig/NEWR-de5fcb2e.png?t=1720244493",
             prerequisites=[CallablePrerequisite(callable=self.prerequisites_callable)],
             tools=[
