@@ -11,13 +11,15 @@ from holmes.core.tools import (
 )
 
 from pydantic import BaseModel, PrivateAttr
-from holmes.core.tools import StructuredToolResult, ToolResultStatus
+from holmes.core.tools import StructuredToolResult, StructuredToolResultStatus
 from holmes.plugins.toolsets.utils import (
     process_timestamps_to_rfc3339,
     standard_start_datetime_tool_param_description,
+    toolset_name_for_one_liner,
+)
+from holmes.plugins.toolsets.logging_utils.logging_api import (
+    DEFAULT_TIME_SPAN_SECONDS,
 )
-
-DEFAULT_TIME_SPAN_SECONDS = 3600
 
 
 class ServiceNowConfig(BaseModel):
@@ -84,15 +86,16 @@ class ServiceNowBaseTool(Tool):
         response.raise_for_status()
         res = response.json()
         return StructuredToolResult(
-            status=ToolResultStatus.SUCCESS
+            status=StructuredToolResultStatus.SUCCESS
             if res.get(field, [])
-            else ToolResultStatus.NO_DATA,
+            else StructuredToolResultStatus.NO_DATA,
             data=res,
             params=params,
         )
 
     def get_parameterized_one_liner(self, params) -> str:
-        return f"ServiceNow {self.name} {params}"
+        # Default implementation - will be overridden by subclasses
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: ServiceNow {self.name} {params}"
 
 
 class ReturnChangesInTimerange(ServiceNowBaseTool):
@@ -108,7 +111,13 @@ class ReturnChangesInTimerange(ServiceNowBaseTool):
         )
     }
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def get_parameterized_one_liner(self, params) -> str:
+        start = params.get("start", "last hour")
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Get Change Requests ({start})"
+
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         parsed_params = {}
         try:
             (start, _) = process_timestamps_to_rfc3339(
@@ -130,7 +139,7 @@ class ReturnChangesInTimerange(ServiceNowBaseTool):
         except Exception as e:
             logging.exception(self.get_parameterized_one_liner(params))
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 data=f"Exception {self.name}: {str(e)}",
                 params=params,
             )
@@ -147,7 +156,13 @@ class ReturnChange(ServiceNowBaseTool):
         )
     }
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def get_parameterized_one_liner(self, params) -> str:
+        sys_id = params.get("sys_id", "")
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Get Change Details ({sys_id})"
+
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         try:
             url = "https://{instance}.service-now.com/api/now/v2/table/change_request/{sys_id}".format(
                 instance=self.toolset.config.get("instance"),
@@ -158,7 +173,7 @@ class ReturnChange(ServiceNowBaseTool):
         except Exception as e:
             logging.exception(self.get_parameterized_one_liner(params))
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 data=f"Exception {self.name}: {str(e)}",
                 params=params,
             )
@@ -175,7 +190,13 @@ class ReturnChangesWithKeyword(ServiceNowBaseTool):
         )
     }
 
-    def _invoke(self, params: Any) -> StructuredToolResult:
+    def get_parameterized_one_liner(self, params) -> str:
+        keyword = params.get("keyword", "")
+        return f"{toolset_name_for_one_liner(self.toolset.name)}: Search Changes ({keyword})"
+
+    def _invoke(
+        self, params: dict, user_approved: bool = False
+    ) -> StructuredToolResult:
         parsed_params = {}
         try:
             url = f"https://{self.toolset.config.get('instance')}.service-now.com/api/now/v2/table/change_request"
@@ -192,7 +213,7 @@ class ReturnChangesWithKeyword(ServiceNowBaseTool):
         except Exception as e:
             logging.exception(self.get_parameterized_one_liner(params))
             return StructuredToolResult(
-                status=ToolResultStatus.ERROR,
+                status=StructuredToolResultStatus.ERROR,
                 data=f"Exception {self.name}: {str(e)}",
                 params=params,
             )
